@@ -2,12 +2,17 @@
 #include <QDebug>
 #include <QPushButton>
 #include <QDate>
+#include <QSlider>
 SwipeCounter::SwipeCounter(){
 
     this->setFixedSize(200,100);
     if(set.value("reset_date",0)==0){
         set.setValue("reset_date",QDate::currentDate ());
     }
+    if(!set.contains("opacity")){
+        set.setValue("opacity",140);
+    }
+
     swipes = set.value("swipes",0).toInt();
     dist = swipes*7.6;
     QVBoxLayout *lay  = new QVBoxLayout;
@@ -27,11 +32,17 @@ SwipeCounter::SwipeCounter(){
     lay->setAlignment(Qt::AlignCenter);
     setLayout(lay);
     setAttribute(Qt::WA_TranslucentBackground);
+    setWindowOpacity(0.9);
 }
 void SwipeCounter::showSettingsDialog(){
 
     dialog = new QDialog();
     dialog->setWindowTitle("SwipeCounter");
+    QSlider *slider = new QSlider(Qt::Horizontal,dialog);
+    connect(slider,SIGNAL(valueChanged(int)),this,SLOT(valueChanged(int)));
+    slider->setMinimum(0);
+    slider->setMaximum(254);
+    slider->setValue(set.value("opacity").toInt());
     QLabel *label = new QLabel(dialog);
     label->setText("SwipeCounter v0.2  Sampo Savola 2010" );
     label->setAlignment(Qt::AlignHCenter | Qt::AlignVCenter);
@@ -44,6 +55,8 @@ void SwipeCounter::showSettingsDialog(){
 
     QVBoxLayout *lay = new QVBoxLayout(dialog);
     lay->addWidget(label);
+    lay->addWidget(new QLabel("Set opacity:",dialog));
+    lay->addWidget(slider);
     lay->addWidget(resetdate);
     lay->addWidget(reset);
     lay->setAlignment(Qt::AlignCenter);
@@ -73,3 +86,18 @@ void SwipeCounter::resetCounter(){
     reset->setDisabled(true);
     dialog->close();
 }
+void SwipeCounter::paintEvent(QPaintEvent *event){
+
+    QPainter p(this);
+    p.setBrush(QColor(0, 0, 0, set.value("opacity").toInt()));
+    p.setPen(Qt::NoPen);
+    p.drawRoundedRect(rect(), 25, 25);
+    p.end();
+}
+void SwipeCounter::valueChanged(int value){
+
+    set.setValue("opacity",value);
+    this->repaint();
+
+}
+
