@@ -21,6 +21,7 @@ public slots:
     void showSettingsDialog();
     void desktopChanged();
     void resetCounter();
+    void valueChanged(int value);
 private:
     QLabel *count;
     QLabel *distance;
@@ -30,6 +31,10 @@ private:
     QSettings set;
     QPushButton *reset;
     QDialog *dialog;
+    int opacity;
+protected:
+
+    void paintEvent(QPaintEvent *);
 };
 
 
